==> mozdom4java-1.1.zip: org/mozilla/dom/UserDataHandlerImpl.java <==


/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozdom4java
 *
 * The Initial Developer of the Original Code is
 * Peter Szinek, Lixto Software GmbH, http://www.lixto.com.
 * Portions created by the Initial Developer are Copyright (C) 2005-2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Peter Szinek (peter@rubyrailways.com)
 *  Michal Ceresna (michal.ceresna@gmail.com)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */


package org.mozilla.dom;

//Java imports
import java.util.*;

//org.w3c imports
import org.w3c.dom.*;
import org.w3c.dom.html2.*;
import org.w3c.dom.html.*;
import org.w3c.dom.events.*;
import org.w3c.dom.traversal.*;
import org.w3c.dom.ranges.*;
import org.w3c.dom.views.*;

//mozdom4java imports
import org.mozilla.dom.*;
import org.mozilla.dom.views.*;

//XPCOM import
import org.mozilla.xpcom.*;
import org.mozilla.interfaces.*;


public class UserDataHandlerImpl implements org.w3c.dom.UserDataHandler
{
    protected nsIDOMUserDataHandler moz;
    protected static WeakValueHashMap instances = new WeakValueHashMap();
    
    public UserDataHandlerImpl(nsIDOMUserDataHandler mozInst)
    {
        moz = mozInst;
        instances.put(mozInst, this);
    }    

    public static UserDataHandlerImpl getDOMInstance(nsIDOMUserDataHandler mozInst)
    {
        UserDataHandlerImpl node = (UserDataHandlerImpl) instances.get(mozInst);
        return node == null ? new UserDataHandlerImpl(mozInst) : node;
    }
    
    public nsIDOMUserDataHandler getInstance()
    {
        //This was already queryinterfaced, so safe to cast
        return (nsIDOMUserDataHandler) moz;
    }
    
    public void handle(short operation, String key, Object data, Node src, Node dst)
    {
        nsIDOMNode mozSrc = ((NodeImpl) src).getInstance();
        nsIDOMNode mozDst = ((NodeImpl) dst).getInstance();
        nsIVariant casted_data = (nsIVariant) data;
        getInstance().handle(operation, key, casted_data, mozSrc, mozDst);
    }
    
}

==> mozdom4java-1.3.zip: org/mozilla/dom/UserDataHandlerImpl.java <==


/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozdom4java
 *
 * The Initial Developer of the Original Code is
 * Peter Szinek, Lixto Software GmbH, http://www.lixto.com.
 * Portions created by the Initial Developer are Copyright (C) 2005-2006
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *  Peter Szinek (peter@rubyrailways.com)
 *  Michal Ceresna (michal.ceresna@gmail.com)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */


package org.mozilla.dom;

//Java imports
import java.util.*;
import java.util.concurrent.*;

//org.w3c imports
import org.w3c.dom.*;
import org.w3c.dom.html2.*;
import org.w3c.dom.html.*;
import org.w3c.dom.events.*;
import org.w3c.dom.traversal.*;
import org.w3c.dom.ranges.*;
import org.w3c.dom.views.*;

//mozdom4java imports
import org.mozilla.dom.*;
import org.mozilla.dom.views.*;
import org.mozilla.dom.events.*;
import org.mozilla.dom.ranges.*;
import org.mozilla.dom.traversal.*;

//XPCOM import
import org.mozilla.xpcom.*;
import org.mozilla.interfaces.*;


public class UserDataHandlerImpl implements org.w3c.dom.UserDataHandler
{

    protected nsIDOMUserDataHandler moz;
    protected static WeakValueHashMap instances = new WeakValueHashMap();

    public nsIDOMUserDataHandler getInstance()
    {
	return getInstanceAsnsIDOMUserDataHandler();
    }

    /***************************************************************
     *
     * UserDataHandler implementation code
     *
     ***************************************************************/

    public UserDataHandlerImpl(nsIDOMUserDataHandler mozInst)
    {
        moz = mozInst;
        instances.put(mozInst, this);
    }

    public static UserDataHandlerImpl getDOMInstance(nsIDOMUserDataHandler mozInst)
    {
        
        UserDataHandlerImpl node = (UserDataHandlerImpl) instances.get(mozInst);
        return node == null ? new UserDataHandlerImpl(mozInst) : node;
    }

    public nsIDOMUserDataHandler getInstanceAsnsIDOMUserDataHandler()
    {
        return moz;
    }

    public void handle(final short operation, final String key, final Object data, final Node src, final Node dst)
    {
        //METHOD-BODY-START - autogenerated code
        final nsIDOMNode mozSrc = src!=null ? ((NodeImpl) src).getInstance() : null;
        final nsIDOMNode mozDst = dst!=null ? ((NodeImpl) dst).getInstance() : null;
        final nsIVariant casted_data = (nsIVariant) data;
        final Runnable r = new Runnable() { public void run() {
            getInstanceAsnsIDOMUserDataHandler().handle(operation, key, casted_data, mozSrc, mozDst);
        }};
        ThreadProxy.getSingleton().syncExec(r);
        //METHOD-BODY-END - autogenerated code
    }



}
